==> qt6-base-6.3.0-3-aarch64.pkg.tar.xz: usr/lib/cmake/Qt6CoreTools/Qt6CoreToolsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::moc" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::moc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::moc PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/moc"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::moc )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::moc "${_IMPORT_PREFIX}/lib/qt6/moc" )

# Import target "Qt6::rcc" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::rcc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::rcc PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/rcc"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::rcc )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::rcc "${_IMPORT_PREFIX}/lib/qt6/rcc" )

# Import target "Qt6::tracegen" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::tracegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::tracegen PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/tracegen"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::tracegen )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::tracegen "${_IMPORT_PREFIX}/lib/qt6/tracegen" )

# Import target "Qt6::cmake_automoc_parser" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::cmake_automoc_parser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::cmake_automoc_parser PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/cmake_automoc_parser"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::cmake_automoc_parser )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::cmake_automoc_parser "${_IMPORT_PREFIX}/lib/qt6/cmake_automoc_parser" )

# Import target "Qt6::qlalr" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qlalr APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qlalr PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/qlalr"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qlalr )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qlalr "${_IMPORT_PREFIX}/lib/qt6/qlalr" )

# Import target "Qt6::qtpaths" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qtpaths APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qtpaths PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/qtpaths"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qtpaths )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qtpaths "${_IMPORT_PREFIX}/lib/qt6/bin/qtpaths" )

# Import target "Qt6::androiddeployqt" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::androiddeployqt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::androiddeployqt PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/androiddeployqt"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::androiddeployqt )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::androiddeployqt "${_IMPORT_PREFIX}/lib/qt6/bin/androiddeployqt" )

# Import target "Qt6::androidtestrunner" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::androidtestrunner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::androidtestrunner PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/androidtestrunner"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::androidtestrunner )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::androidtestrunner "${_IMPORT_PREFIX}/lib/qt6/bin/androidtestrunner" )

# Import target "Qt6::qmake" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmake APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmake PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/qmake"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::qmake )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::qmake "${_IMPORT_PREFIX}/lib/qt6/bin/qmake" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qt6-base-6.4.0-2-aarch64.pkg.tar.xz: usr/lib/cmake/Qt6CoreTools/Qt6CoreToolsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::moc" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::moc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::moc PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/moc"
  )

list(APPEND _cmake_import_check_targets Qt6::moc )
list(APPEND _cmake_import_check_files_for_Qt6::moc "${_IMPORT_PREFIX}/lib/qt6/moc" )

# Import target "Qt6::rcc" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::rcc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::rcc PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/rcc"
  )

list(APPEND _cmake_import_check_targets Qt6::rcc )
list(APPEND _cmake_import_check_files_for_Qt6::rcc "${_IMPORT_PREFIX}/lib/qt6/rcc" )

# Import target "Qt6::tracegen" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::tracegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::tracegen PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/tracegen"
  )

list(APPEND _cmake_import_check_targets Qt6::tracegen )
list(APPEND _cmake_import_check_files_for_Qt6::tracegen "${_IMPORT_PREFIX}/lib/qt6/tracegen" )

# Import target "Qt6::cmake_automoc_parser" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::cmake_automoc_parser APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::cmake_automoc_parser PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/cmake_automoc_parser"
  )

list(APPEND _cmake_import_check_targets Qt6::cmake_automoc_parser )
list(APPEND _cmake_import_check_files_for_Qt6::cmake_automoc_parser "${_IMPORT_PREFIX}/lib/qt6/cmake_automoc_parser" )

# Import target "Qt6::qlalr" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qlalr APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qlalr PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/qlalr"
  )

list(APPEND _cmake_import_check_targets Qt6::qlalr )
list(APPEND _cmake_import_check_files_for_Qt6::qlalr "${_IMPORT_PREFIX}/lib/qt6/qlalr" )

# Import target "Qt6::qtpaths" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qtpaths APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qtpaths PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/qtpaths"
  )

list(APPEND _cmake_import_check_targets Qt6::qtpaths )
list(APPEND _cmake_import_check_files_for_Qt6::qtpaths "${_IMPORT_PREFIX}/lib/qt6/bin/qtpaths" )

# Import target "Qt6::androiddeployqt" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::androiddeployqt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::androiddeployqt PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/androiddeployqt"
  )

list(APPEND _cmake_import_check_targets Qt6::androiddeployqt )
list(APPEND _cmake_import_check_files_for_Qt6::androiddeployqt "${_IMPORT_PREFIX}/lib/qt6/bin/androiddeployqt" )

# Import target "Qt6::androidtestrunner" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::androidtestrunner APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::androidtestrunner PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/androidtestrunner"
  )

list(APPEND _cmake_import_check_targets Qt6::androidtestrunner )
list(APPEND _cmake_import_check_files_for_Qt6::androidtestrunner "${_IMPORT_PREFIX}/lib/qt6/bin/androidtestrunner" )

# Import target "Qt6::qmake" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::qmake APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::qmake PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/qt6/bin/qmake"
  )

list(APPEND _cmake_import_check_targets Qt6::qmake )
list(APPEND _cmake_import_check_files_for_Qt6::qmake "${_IMPORT_PREFIX}/lib/qt6/bin/qmake" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
